@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "rfc-mode" "1.4.2"
+(define-package "rfc-mode" "20260127.1807"
   "RFC document browser and viewer."
   '((emacs "25.1"))
   :url "https://github.com/galdor/rfc-mode"
-  :commit "ab09db78d9d1baa4da4f926930833598e1e978ce"
-  :revdesc "v1.4.2-0-gab09db78d9d1"
+  :commit "2d3dcd649e291eeb93091560b504f96162371c32"
+  :revdesc "2d3dcd649e29"
   :authors '(("Nicolas Martyanoff" . "nicolas@n16f.net"))
   :maintainers '(("Nicolas Martyanoff" . "nicolas@n16f.net")))
