@@ -3,8 +3,8 @@
 ;; Author: Nicolas Martyanoff <nicolas@n16f.net>
 ;; SPDX-License-Identifier: ISC
 ;; URL: https://github.com/galdor/rfc-mode
-;; Package-Version: 1.4.2
-;; Package-Revision: v1.4.2-0-gab09db78d9d1
+;; Package-Version: 20260127.1807
+;; Package-Revision: 2d3dcd649e29
 ;; Package-Requires: ((emacs "25.1"))
 
 ;;; Commentary:
@@ -241,6 +241,16 @@ Offer the number at point as default."
   (interactive)
   (setq rfc-mode-index-entries nil))
 
+;;;###autoload
+(defun rfc-mode-update-index ()
+  "Force download and rebuild of the RFC index."
+  (interactive)
+  (message "Updating RFC index...")
+  (let ((file (rfc-mode--download-index)))
+    (setq rfc-mode-index-entries
+          (rfc-mode-read-index-file file)))
+  (message "RFC index updated successfully."))
+
 (defun rfc-mode--index-entries ()
   (or rfc-mode-index-entries
       (let ((file (rfc-mode--document-file "-index")))
@@ -412,6 +422,15 @@ ENTRY is a RFC index entry in the browser."
 
 ;;; Index utils:
 
+
+(defun rfc-mode--download-index ()
+  "Download the RFC index file and return its local filename."
+  (let ((file (rfc-mode--document-file "-index")))
+    ;; Force re-download by deleting existing file first
+    (when (file-exists-p file)
+      (delete-file file))
+    (rfc-mode--document-file "-index")))
+
 (defun rfc-mode-read-index-file (filename)
   "Read an RFC index file at FILENAME and return a list of entries."
   (with-temp-buffer
